@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiLastBoss.cpp,v 1.18 2009/06/06 06:27:31 bowkenken Exp $
+* $Id: GuiLastBoss.cpp,v 1.19 2009/08/09 01:43:21 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -243,7 +243,7 @@ void GuiLastBoss::initPcg( Pcg *pcg, WSCstring dirName )
 	// 
 
 	if( nFileMaxN > 0 )
-		nFileSelN = randm( nFileMaxN );
+		nFileSelN = gui_randm( nFileMaxN );
 	else
 		nFileSelN = -1;
 
