@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: Key.cpp,v 1.25 2009/08/15 04:46:06 bowkenken Exp $
+* $Id: Key.cpp,v 1.27 2009/08/31 08:05:08 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -442,7 +442,7 @@ gboolean handleKeyPress(
 	case GDK_F35:
 		char buf[15 + 1];
 		sprintf( buf, "&f%ld;", key - GDK_F1 );
-		gKey.setString( buf, true, true );
+		gKey.setString( buf );
 
 		return 1;
 	}
@@ -612,7 +612,7 @@ void Key::handleKeyDown(
 	case VK_F24:
 		char buf[15 + 1];
 		sprintf( buf, "&%02ld", key - VK_F1 + 1 );
-		setString( buf, true, true );
+		setString( buf );
 
 		return;
 	}
@@ -809,7 +809,7 @@ bool Key::moveCrsrAbs( long mapX, long mapY )
 	crsr->x = mapX;
 	crsr->y = mapY;
 	CheckMoveCrsr();
-	setString( "|", true );
+	setString( "|", false, true );
 
 	return true;
 }
@@ -896,7 +896,7 @@ bool Key::scrollAbs( long mapX, long mapY )
 	draw_gui->x = mapX;
 	draw_gui->y = mapY;
 	CheckScroll();
-	setString( "|", true );
+	setString( "|", false, true );
 
 	return true;
 }
