@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: MouseMap.cpp,v 1.37 2009/07/04 01:23:58 bowkenken Exp $
+* $Id: MouseMap.cpp,v 1.41 2009/08/15 04:46:06 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -330,7 +330,7 @@ void funcMotionLeftR(
 	long nCurX, long nCurY
 )
 {
-	callFuncKey( FUNC_N_MOTION_LEFT );
+	callFuncKey( KEY_N_MOUSE_MOTION( KEY_N_MOUSE_MOTION_LEFT ) );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -348,7 +348,7 @@ void funcMotionRightR(
 	long nCurX, long nCurY
 )
 {
-	callFuncKey( FUNC_N_MOTION_RIGHT );
+	callFuncKey( KEY_N_MOUSE_MOTION( KEY_N_MOUSE_MOTION_RIGHT ) );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -366,7 +366,7 @@ void funcMotionUpR(
 	long nCurX, long nCurY
 )
 {
-	callFuncKey( FUNC_N_MOTION_UP );
+	callFuncKey( KEY_N_MOUSE_MOTION( KEY_N_MOUSE_MOTION_UP ) );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -384,7 +384,7 @@ void funcMotionDownR(
 	long nCurX, long nCurY
 )
 {
-	callFuncKey( FUNC_N_MOTION_DOWN );
+	callFuncKey( KEY_N_MOUSE_MOTION( KEY_N_MOUSE_MOTION_DOWN ) );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -414,40 +414,21 @@ void funcMotionClick(
 	if( n >= MouseMotion::nMouseButtonMaxN )
 		return;
 
-#if	0
-//@@@
-	if( n == MouseMotion::nMouseButtonL ){
-		gKey.setChar( 'M' - '@' );
-	} else if( n == MouseMotion::nMouseButtonM ){
-		gKey.setString( "+" );
-	} else if( n == MouseMotion::nMouseButtonR ){
-		gKey.setString( "." );
-	} else if( n == MouseMotion::nMouseButton3 ){
-print_msg( 0, "33333" );//@@@
-		gKey.setString( "Q" );
-	} else if( n == MouseMotion::nMouseButton4 ){
-print_msg( 0, "44444" );//@@@
-		gKey.setString( "Q" );
-	} else if( n == MouseMotion::nMouseButton5 ){
-print_msg( 0, "55555" );//@@@
-		gKey.setString( "Q" );
-	} else if( n == MouseMotion::nMouseButton6 ){
-		gKey.setString( "6" );
-	} else {
-		char str[15 + 1];
-		sprintf( str, "&%2ld", (long)n );
-		gKey.setString( str );
-	}
-#else
 	if( chk_scene_group( SCENE_GROUP_N_SEL_GRAPH ) ){
 		if( n == MouseMotion::nMouseButtonL )
 			gSelMbrGraph->sel( nBgnX, nBgnY );
 		if( n == MouseMotion::nMouseButtonR )
 			gSelMbrGraph->cancel();
+	} else if( chk_scene_group( SCENE_GROUP_N_SPACE ) ){
+		if( gPcgDun.pDemoEnding != NULL ){
+			if( n == MouseMotion::nMouseButtonL )
+				gPcgDun.pDemoEnding->space.addSpeedZ( +1 );
+			if( n == MouseMotion::nMouseButtonR )
+				gPcgDun.pDemoEnding->space.addSpeedZ( -1 );
+		}
 	} else {
-		callFuncKey( FUNC_N_CLICK_0 + n, true );
+		callFuncKey( KEY_N_MOUSE_CLICK( n ), true );
 	}
-#endif
 }
 
 ////////////////////////////////////////////////////////////////
@@ -478,7 +459,7 @@ void funcMotionDoubleClick(
 	} else {
 		if( n == MouseMotion::nMouseButtonL ){
 			unset_square_pos();
-			gKey.setChar( 'M' - '@' );
+			callFuncKey( KEY_N_MOUSE_D_CLICK( n ), true );
 		}
 	}
 }
@@ -505,27 +486,15 @@ void funcMotionClickLR(
 
 	MouseMotion::MouseButtonN n = (MouseMotion::MouseButtonN)m;
 
-#if	1
-	long fn = FUNC_N_CLICK_0;
-
+	long fn = KEY_N_MOUSE_PRESS_L_CLICK_R;
 	if( n == MouseMotion::nMouseButtonL )
-		fn = FUNC_N_PRESS_L_CLICK_R;
+		fn = KEY_N_MOUSE_PRESS_L_CLICK_R;
 	else if( n == MouseMotion::nMouseButtonR )
-		fn = FUNC_N_PRESS_R_CLICK_L;
+		fn = KEY_N_MOUSE_PRESS_R_CLICK_L;
 	else
 		return;
 
-	callFuncKey( fn );
-#else
-//@@@
-	if( n == MouseMotion::nMouseButtonL ){
-		gKey.setStringKeyTab( "&11" );
-	}
-
-	if( n == MouseMotion::nMouseButtonR ){
-		gKey.setStringKeyTab( "&12" );
-	}
-#endif
+	callFuncKey( KEY_N_MOUSE_P_CLICK( n ) );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -577,7 +546,7 @@ void funcMotionRelease(
 
 	endPressTimer( n );
 
-	callFuncKey( FUNC_N_RELEASE_0 + n );
+	callFuncKey( KEY_N_MOUSE_RELEASE( n ) );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -686,7 +655,7 @@ void callBackPressTimer( void )
 	for( long i = (long)MouseMotion::nMouseButtonMinN;
 			i < (long)MouseMotion::nMouseButtonMaxN; i++ ){
 		if( bFlagPressTimer[i] )
-			callFuncKey( FUNC_N_PRESS_0 + i );
+			callFuncKey( KEY_N_MOUSE_PRESS( i ) );
 
 		bFlagPressTimer[i] = false;
 	}
@@ -737,6 +706,8 @@ void funcMotionScroll(
 	default:
 		break;
 	}
+
+	gKey.setString( "|" );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -748,9 +719,9 @@ void funcMotionScroll(
 
 bool callFuncKey( long fn, bool flagCheckClear )
 {
-	if( fn < 0 )
+	if( fn < KEY_N_0 )
 		return false;
-	if( fn > FUNC_KEY_MAX )
+	if( fn > KEY_N_MAX )
 		return false;
 
 	do {
@@ -766,8 +737,8 @@ bool callFuncKey( long fn, bool flagCheckClear )
 		return true;
 	} while( 0 );
 
-	char str[15 + 1];
-	sprintf( str, "&%2ld", (long)fn );
+	char str[63 + 1];
+	sn_printf( str, 63, "&a0x%lx;", (long)fn );
 	gKey.setString( str );
 
 	return true;
