@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: PcgDun.h,v 1.70 2009/05/29 04:53:09 bowkenken Exp $
+* $Id: PcgDun.h,v 1.71 2009/08/28 05:40:19 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_DUN_H
@@ -92,7 +92,7 @@
 // ѥΥơ֥
 struct PcgTab {
 	// 󥹥ξμ
-	mnstr_kind_t nMnstrKind;
+	long	nKind;
 	// ʸ
 	char mjr, mnr;
 	// ѥλȤ
@@ -175,8 +175,8 @@ private:
 	Pcg pcgWindowOpen;
 
 	// ΥѥΥꥹ
-	Pcg pcgCrsr;
-	Pcg pcgCrsrSub;
+	Pcg *aPcgCrsr[ATTITUDE_MAX_N];
+	Pcg *aPcgCrsrSub[ATTITUDE_MAX_N];
 	// 󥫡ΥѥΥꥹ
 	Pcg pcgSquareParty;
 	Pcg pcgSquareMbr;
@@ -359,6 +359,7 @@ public:
 	long getObjDrawBottom( long mapY, Pcg *pPcg );
 	long getObjDrawHeight( long mapY, Pcg *pPcg );
 
+	Pcg *getCrsr( long mapX, long mapY, bool flagSub );
 	long getCrsrWidth( bool flagSub );
 	long getCrsrHeight( bool flagSub );
 
@@ -551,6 +552,7 @@ private:
 	bool chkDrawSignboard( long mapX, long mapY );
 	bool chkDrawSanctuary( long mapX, long mapY, trap_t *trap );
 /*
+	Pcg *getCrsr( long mapX, long mapY, bool flagSub );
 	long getCrsrWidth( bool flagSub );
 	long getCrsrHeight( bool flagSub );
 */
