@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: call.cpp,v 1.107 2009/07/04 01:24:13 bowkenken Exp $
+* $Id: call.cpp,v 1.112 2009/09/06 15:35:51 bowkenken Exp $
 ***************************************************************/
 
 #define	CALL_CPP
@@ -225,7 +225,6 @@ void	call_gui_menu_wipe( void )
 
 void	call_set_mouse_dflt_menu( long sel_n )
 {
-#ifndef D_MFC
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
 		return;
@@ -238,7 +237,6 @@ void	call_set_mouse_dflt_menu( long sel_n )
 
 	gui_end();
 #endif
-#endif // ! D_MFC
 }
 
 /***************************************************************
@@ -1069,7 +1067,13 @@ void	call_pcg_dun_scroll( long map_x, long map_y )
 long	call_pcg_dun_get_crsr_width( bool_t flagSub )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
-	return gPcgDun.getCrsrWidth( !!flagSub );
+	gui_begin();
+
+	long n = gPcgDun.getCrsrWidth( !!flagSub );
+
+	gui_end();
+
+	return n;
 #endif
 
 	return 0;
@@ -1084,7 +1088,13 @@ long	call_pcg_dun_get_crsr_width( bool_t flagSub )
 long	call_pcg_dun_get_crsr_height( bool_t flagSub )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
-	return gPcgDun.getCrsrHeight( !!flagSub );
+	gui_begin();
+
+	long n = gPcgDun.getCrsrHeight( !!flagSub );
+
+	gui_end();
+
+	return n;
 #endif
 
 	return 0;
@@ -1113,11 +1123,15 @@ long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool_t flagPre )
 			return get_chr_left( chr->x, chr->dx );
 	}
 
+	gui_begin();
+
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
 	long n = gPcgDun.getChrDrawLeft( chr, pPcg, bFlagPre );
 	n = n / gPcgDun.getTileSizeX();
 
+	gui_end();
+
 	return n;
 #endif
 
@@ -1150,11 +1164,15 @@ long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool_t flagPre )
 			return get_chr_right( chr->x, chr->dx );
 	}
 
+	gui_begin();
+
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
 	long n = gPcgDun.getChrDrawRight( chr, pPcg, bFlagPre );
 	n = (n + gPcgDun.getTileSizeX() - 1) / gPcgDun.getTileSizeX();
 
+	gui_end();
+
 	return n;
 #endif
 
@@ -1187,11 +1205,15 @@ long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool_t flagPre )
 			return get_chr_top( chr->y, chr->dy );
 	}
 
+	gui_begin();
+
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
 	long n = gPcgDun.getChrDrawTop( chr, pPcg, bFlagPre );
 	n = n / gPcgDun.getTileSizeY();
 
+	gui_end();
+
 	return n;
 #endif
 
@@ -1224,11 +1246,15 @@ long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool_t flagPre )
 			return get_chr_bottom( chr->y, chr->dy );
 	}
 
+	gui_begin();
+
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
 	long n = gPcgDun.getChrDrawBottom( chr, pPcg, bFlagPre );
 	n = (n + gPcgDun.getTileSizeY() - 1) / gPcgDun.getTileSizeY();
 
+	gui_end();
+
 	return n;
 #endif
 
@@ -1242,13 +1268,22 @@ long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool_t flagPre )
 * ɸޥåסɥɽϰ⤫Ĵ٤
 * long mapX : Xɸ
 * long mapY : Yɸ
+* bool_t flg_gui : GUI ƤФ줿?
 * return : ޥåסɥɽϰ⤫?
 ***************************************************************/
 
-bool_t	call_pcg_dun_clip_win( long mapX, long mapY )
+bool_t	call_pcg_dun_clip_win( long mapX, long mapY, bool_t flg_gui )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
-	return gPcgDun.clipWin( mapX, mapY );
+	if( !flg_gui )
+		gui_begin();
+
+	bool_t flg = gPcgDun.clipWin( mapX, mapY );
+
+	if( !flg_gui )
+		gui_end();
+
+	return flg;
 #endif
 
 	return TRUE;
@@ -1260,10 +1295,18 @@ bool_t	call_pcg_dun_clip_win( long mapX, long mapY )
 * return : ޥåסɥɽϰ⤫?
 ***************************************************************/
 
-bool_t	call_pcg_dun_clip_win_x( long mapX )
+bool_t	call_pcg_dun_clip_win_x( long mapX, bool_t flg_gui )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
-	return gPcgDun.clipWinX( mapX );
+	if( !flg_gui )
+		gui_begin();
+
+	bool_t flg = gPcgDun.clipWinX( mapX );
+
+	if( !flg_gui )
+		gui_end();
+
+	return flg;
 #endif
 
 	return TRUE;
@@ -1275,18 +1318,25 @@ bool_t	call_pcg_dun_clip_win_x( long mapX )
 * return : ޥåסɥɽϰ⤫?
 ***************************************************************/
 
-bool_t	call_pcg_dun_clip_win_y( long mapY )
+bool_t	call_pcg_dun_clip_win_y( long mapY, bool_t flg_gui )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
-	return gPcgDun.clipWinY( mapY );
+	if( !flg_gui )
+		gui_begin();
+
+	bool_t flg = gPcgDun.clipWinY( mapY );
+
+	if( !flg_gui )
+		gui_end();
+
+	return flg;
 #endif
 
 	return TRUE;
 }
 
 /***************************************************************
-* 饹ܥΥǥ⤬äĴ٤
-* return : ǥ⤬ä?
+* 饹ܥΥǥꥻå
 ***************************************************************/
 
 void	call_demo_last_boss_reset( void )
@@ -1300,7 +1350,11 @@ void	call_demo_last_boss_reset( void )
 	if( gPcgDun.pDemoLastBoss == NULL )
 		return;
 
+	gui_begin();
+
 	gPcgDun.pDemoLastBoss->reset();
+
+	gui_end();
 #endif
 }
 
@@ -1317,13 +1371,30 @@ bool_t	call_demo_last_boss_check_done( void )
 	if( !g_flg_gui )
 		return TRUE;
 
-	if( gPcgDun.pDemoLastBoss == NULL )
-		return TRUE;
+	bool_t	flg = TRUE;
 
-	if( gPcgDun.pDemoLastBoss->checkDone() )
-		return TRUE;
-	else
-		return FALSE;
+	// gui_begin();
+
+	do {
+		if( gPcgDun.pDemoLastBoss == NULL ){
+			flg = TRUE;
+			break;
+		}
+
+		if( gPcgDun.pDemoLastBoss->checkDone() ){
+			flg = TRUE;
+			break;
+		} else {
+			flg = FALSE;
+			break;
+		}
+
+		break;
+	} while( 0 );
+
+	// gui_end();
+
+	return flg;
 #endif
 
 	return TRUE;
@@ -1419,17 +1490,13 @@ void	call_game_sound_stop( void )
 long	call_game_joystick_get_joy( void )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
-	{
-		long	n;
+	gui_begin();
 
-		gui_begin();
+	long n = gJoystick.getJoy();
 
-		n = gJoystick.getJoy();
+	gui_end();
 
-		gui_end();
-
-		return n;
-	}
+	return n;
 #endif
 
 	return g_joy_n;
@@ -1462,17 +1529,13 @@ void	call_game_joystick_sel_joy( long n )
 const char	*call_game_joystick_get_name( long n )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
-	{
-		const char	*s;
+	gui_begin();
 
-		gui_begin();
+	const char	*s = gJoystick.getName( n );
 
-		s = gJoystick.getName( n );
+	gui_end();
 
-		gui_end();
-
-		return s;
-	}
+	return s;
 #endif
 
 	return NULL;
@@ -1486,17 +1549,13 @@ const char	*call_game_joystick_get_name( long n )
 long	call_game_joystick_get_kind( void )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
-	{
-		long	n;
+	gui_begin();
 
-		gui_begin();
+	long n = gJoystick.getKind();
 
-		n = gJoystick.getKind();
+	gui_end();
 
-		gui_end();
-
-		return n;
-	}
+	return n;
 #endif
 
 	return g_joy_kind;
