@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.c,v 1.164 2009/07/30 12:16:15 bowkenken Exp $
+* $Id: fight.c,v 1.166 2009/09/11 19:26:26 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -87,12 +87,12 @@
 
 /* 󥯤Υ٥˴ */
 
-#define	HIT_MON_MUL	10
-#define	HIT_MON_ADD	20
-#define	DAM_MON_MUL	10
-#define	DAM_MON_ADD	20
-#define	DEF_MON_MUL	10
-#define	DEF_MON_ADD	20
+#define	HIT_MON_MUL	6
+#define	HIT_MON_ADD	2
+#define	DAM_MON_MUL	6
+#define	DAM_MON_ADD	2
+#define	DEF_MON_MUL	6
+#define	DEF_MON_ADD	2
 
 /* դΥƥ롦ҥåΨ */
 
@@ -312,7 +312,7 @@ bool_t	set_attack_mbr_bash(
 	} else {
 		/* ξ */
 		p = get_attack( flg_ave, wpn_tab->attack, range,
-				TRUE, FALSE, FALSE, FALSE );
+				TRUE, TRUE, FALSE, FALSE );
 		if( p == NULL )
 			return FALSE;
 		*attack = *p;
@@ -1318,8 +1318,9 @@ bool_t	fight_x_1(
 		}
 	}
 
-	print_msg( FLG_NULL, get_msg_attack( attack ), o_name, d_name );
-	print_msg( FLG_NULL, MSG_FIGHT_RESI_KIND,
+	print_msg_find( d_p, FLG_NULL, get_msg_attack( attack ),
+			o_name, d_name );
+	print_msg_find( d_p, FLG_NULL, MSG_FIGHT_RESI_KIND,
 			get_resi_name( attack->resi_kind ) );
 
 	bgn.x = o_p->x;
@@ -1924,7 +1925,8 @@ bool_t	spell_attack(
 
 	/* ᡼ɽ */
 
-	print_msg( FLG_NULL, MSG_FIGHT_RESI_KIND, get_resi_name( resi ) );
+	print_msg_find( d_p, FLG_NULL, MSG_FIGHT_RESI_KIND,
+			get_resi_name( resi ) );
 
 	curs_attrset_chr( d_p, -1, FALSE );
 	print_msg_find( d_p, FLG_NULL, MSG_FIGHT_HIT_STD, d_name, dam );
