@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.135 2009/08/15 06:21:45 bowkenken Exp $
+* $Id: gmain.c,v 1.138 2009/09/06 12:17:21 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -75,7 +75,7 @@ check_memory_def( check_memory_gmain_c_pre_tbuf )
 ***************************************************************/
 
 #define	OPT_ARG_MAX_LEN	128
-#define	STR_OPT	"GCUN:P:T:D:S:l:k:e:s:p:cd:m:Vvh"
+#define	STR_OPT	"GCUN:P:T:D:S:l:k:e:s:p:m:cd:Vvh"
 
 #ifdef	HAVE_GETOPT_LONG
 static struct option	long_opt[] = {
@@ -92,9 +92,9 @@ static struct option	long_opt[] = {
 	{ "echo-key",      required_argument, NULL, 'e' },
 	{ "use-curses",    required_argument, NULL, 's' },
 	{ "use-keypad",    required_argument, NULL, 'p' },
+	{ "check-memory",  required_argument, NULL, 'm' },
 	{ "measure-clock", no_argument,       NULL, 'c' },
 	{ "debug",         required_argument, NULL, 'd' },
-	{ "check-memory",  required_argument, NULL, 'm' },
 	{ "version",       no_argument,       NULL, 'V' },
 	{ "help",          no_argument,       NULL, 'h' },
 	{ 0, 0, 0, 0 }
@@ -136,13 +136,13 @@ char	str_usage[] = {
 	"                             ON or OFF\n"
 	"  -p, --use-keypad=FLAG    use cursor key (call keypad):\n"
 	"                             ON or OFF\n"
+	"  -m, --check-memory=FLAG  check memory:\n"
+	"                             ON or OFF\n"
 	"  -c, --measure-clock      measure frame rate\n"
 #if	defined( DEBUG ) || !defined( NDEBUG )
 	"  -d, --debug=FLAG         set debug mode:\n"
 	"                             ON or OFF\n"
 #endif
-	"  -m, --check-memory=FLAG  check memory:\n"
-	"                             ON or OFF\n"
 	"  -V, -v, --version        display version and exit\n"
 	"  -h, --help               display this help and exit\n"
 };
@@ -395,7 +395,7 @@ void	init_arg( void )
 	g_flg_echo_key = FALSE;
 
 	g_flg_use_curs = TRUE;
-	g_flg_use_keypad = FALSE;
+	g_flg_use_keypad = TRUE;
 
 	g_flg_measure_clk_tck = FALSE;
 	g_flg_check_memory = TRUE;
@@ -506,15 +506,15 @@ void	chk_arg( int argc, char **argv )
 		case 'p':
 			chk_opt_flg( optarg, &g_flg_use_keypad, TRUE );
 			break;
+		case 'm':
+			chk_opt_flg( optarg, &g_flg_check_memory, TRUE );
+			break;
 		case 'c':
 			g_flg_measure_clk_tck = TRUE;
 			break;
 		case 'd':
 			chk_opt_flg( optarg, &g_flg_debug, TRUE );
 			break;
-		case 'm':
-			chk_opt_flg( optarg, &g_flg_check_memory, TRUE );
-			break;
 		case 'V':
 		case 'v':
 			version( stdout );
@@ -1137,6 +1137,7 @@ void	set_key_wait_vtime( long wait_vtime )
 # endif
 
 	/* Խ */
+	tbuf.c_cc[VMIN] = 0;
 	tbuf.c_cc[VTIME] = wait_vtime;
 
 	/* Υå */
