@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-dows.cpp,v 1.35 2009/07/25 20:47:54 bowkenken Exp $
+* $Id: main-dows.cpp,v 1.36 2009/08/22 04:01:08 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -172,12 +172,10 @@ void	printMapStatBar( const char *s, ... )
 	if( theApp.m_pMainFrm == NULL )
 		return;
 
-	CStatusBar &bar = theApp.m_pMainFrm->GetStatusBar();
-	TRY {
-		if( g_flg_init )
-			bar.SetPaneText( bar.CommandToIndex( ID_SEPARATOR ), str );
-	} CATCH( CException, e ){
-	} END_CATCH
+	if( g_flg_init ){
+		CStatusBar &bar = theApp.m_pMainFrm->GetStatusBar();
+		bar.SetWindowText( str );
+	}
 }
 
 ////////////////////////////////////////////////////////////////
