@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-gtk.cpp,v 1.71 2009/07/11 13:57:28 bowkenken Exp $
+* $Id: main-gtk.cpp,v 1.73 2009/07/23 12:25:21 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -37,7 +37,7 @@
 
 ////////////////////////////////////////////////////////////////
 
-#define	FLAG_BTN_MAP_LABEL_IS_NAME	0
+#define	FLAG_BTN_MAP_LABEL_IS_NAME	1
 
 #define	TILE_X_SIZE()	(gPcgDun.getTileSizeX( true ))
 #define	TILE_Y_SIZE()	(gPcgDun.getTileSizeY( true ))
@@ -900,10 +900,18 @@ void	handle_cancel_clicked(
 	GtkWidget *widget, gpointer *data
 )
 {
-	if( chk_scene_group( SCENE_GROUP_N_SEL_GRAPH ) )
-		gSelMbrGraph->cancel();
-	else
-		gKey.setChar( '0', true );
+	switch( get_lang_kind() ){
+	case LANG_KIND_ENGLISH:
+		exec_ok_clicked();
+		break;
+	case LANG_KIND_JAPANESE_EUC:
+	case LANG_KIND_JAPANESE_UTF_8:
+	case LANG_KIND_JAPANESE_SJIS:
+	case LANG_KIND_MAX_N:
+	default:
+		exec_cancel_clicked();
+		break;
+	}
 }
 
 ////////////////////////////////////////////////////////////////
@@ -915,6 +923,38 @@ void	handle_cancel_clicked(
 void	handle_ok_clicked(
 	GtkWidget *widget, gpointer *data
 )
+{
+	switch( get_lang_kind() ){
+	case LANG_KIND_ENGLISH:
+		exec_cancel_clicked();
+		break;
+	case LANG_KIND_JAPANESE_EUC:
+	case LANG_KIND_JAPANESE_UTF_8:
+	case LANG_KIND_JAPANESE_SJIS:
+	case LANG_KIND_MAX_N:
+	default:
+		exec_ok_clicked();
+		break;
+	}
+}
+
+////////////////////////////////////////////////////////////////
+// 󥻥롦ܥν
+////////////////////////////////////////////////////////////////
+
+void	exec_cancel_clicked( void )
+{
+	if( chk_scene_group( SCENE_GROUP_N_SEL_GRAPH ) )
+		gSelMbrGraph->cancel();
+	else
+		gKey.setChar( '0', true );
+}
+
+////////////////////////////////////////////////////////////////
+// OK ܥν
+////////////////////////////////////////////////////////////////
+
+void	exec_ok_clicked( void )
 {
 	if( chk_scene_group( SCENE_GROUP_N_SEL_GRAPH ) )
 		gSelMbrGraph->ok();
